@@ -36,6 +36,8 @@ from .type_defs import (
     DescribeSubscriptionResponseTypeDef,
     EmergencyContactTypeDef,
     GetSubscriptionStateResponseTypeDef,
+    InclusionProtectionFiltersTypeDef,
+    InclusionProtectionGroupFiltersTypeDef,
     ListAttacksResponseTypeDef,
     ListProtectionGroupsResponseTypeDef,
     ListProtectionsResponseTypeDef,
@@ -126,7 +128,7 @@ class ShieldClient(BaseClient):
         """
 
     def associate_proactive_engagement_details(
-        self, *, EmergencyContactList: Sequence["EmergencyContactTypeDef"]
+        self, *, EmergencyContactList: Sequence[EmergencyContactTypeDef]
     ) -> Dict[str, Any]:
         """
         Initializes proactive engagement and sets the list of contacts for the Shield
@@ -144,8 +146,16 @@ class ShieldClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#close)
+        """
+
     def create_protection(
-        self, *, Name: str, ResourceArn: str, Tags: Sequence["TagTypeDef"] = ...
+        self, *, Name: str, ResourceArn: str, Tags: Sequence[TagTypeDef] = ...
     ) -> CreateProtectionResponseTypeDef:
         """
         Enables Shield Advanced for a specific Amazon Web Services resource.
@@ -162,7 +172,7 @@ class ShieldClient(BaseClient):
         Pattern: ProtectionGroupPatternType,
         ResourceType: ProtectedResourceTypeType = ...,
         Members: Sequence[str] = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Creates a grouping of protected resources so they can be handled as a
@@ -275,7 +285,7 @@ class ShieldClient(BaseClient):
     def disable_application_layer_automatic_response(self, *, ResourceArn: str) -> Dict[str, Any]:
         """
         Disable the Shield Advanced automatic application layer DDoS mitigation feature
-        for the resource.
+        for the protected resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disable_application_layer_automatic_response)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#disable_application_layer_automatic_response)
@@ -320,11 +330,11 @@ class ShieldClient(BaseClient):
         """
 
     def enable_application_layer_automatic_response(
-        self, *, ResourceArn: str, Action: "ResponseActionTypeDef"
+        self, *, ResourceArn: str, Action: ResponseActionTypeDef
     ) -> Dict[str, Any]:
         """
         Enable the Shield Advanced automatic application layer DDoS mitigation for the
-        resource.
+        protected resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.enable_application_layer_automatic_response)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#enable_application_layer_automatic_response)
@@ -366,8 +376,8 @@ class ShieldClient(BaseClient):
         self,
         *,
         ResourceArns: Sequence[str] = ...,
-        StartTime: "TimeRangeTypeDef" = ...,
-        EndTime: "TimeRangeTypeDef" = ...,
+        StartTime: TimeRangeTypeDef = ...,
+        EndTime: TimeRangeTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListAttacksResponseTypeDef:
@@ -380,20 +390,28 @@ class ShieldClient(BaseClient):
         """
 
     def list_protection_groups(
-        self, *, NextToken: str = ..., MaxResults: int = ...
+        self,
+        *,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        InclusionFilters: InclusionProtectionGroupFiltersTypeDef = ...
     ) -> ListProtectionGroupsResponseTypeDef:
         """
-        Retrieves the  ProtectionGroup objects for the account.
+        Retrieves  ProtectionGroup objects for the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_protection_groups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#list_protection_groups)
         """
 
     def list_protections(
-        self, *, NextToken: str = ..., MaxResults: int = ...
+        self,
+        *,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        InclusionFilters: InclusionProtectionFiltersTypeDef = ...
     ) -> ListProtectionsResponseTypeDef:
         """
-        Lists all  Protection objects for the account.
+        Retrieves  Protection objects for the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_protections)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#list_protections)
@@ -418,7 +436,7 @@ class ShieldClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/client/#list_tags_for_resource)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds or updates tags for a resource in Shield.
 
@@ -435,7 +453,7 @@ class ShieldClient(BaseClient):
         """
 
     def update_application_layer_automatic_response(
-        self, *, ResourceArn: str, Action: "ResponseActionTypeDef"
+        self, *, ResourceArn: str, Action: ResponseActionTypeDef
     ) -> Dict[str, Any]:
         """
         Updates an existing Shield Advanced automatic application layer DDoS mitigation
@@ -446,7 +464,7 @@ class ShieldClient(BaseClient):
         """
 
     def update_emergency_contact_settings(
-        self, *, EmergencyContactList: Sequence["EmergencyContactTypeDef"] = ...
+        self, *, EmergencyContactList: Sequence[EmergencyContactTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Updates the details of the list of email addresses and phone numbers that the
