@@ -23,10 +23,10 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
+    InclusionProtectionFiltersTypeDef,
     ListAttacksResponseTypeDef,
     ListProtectionsResponseTypeDef,
     PaginatorConfigTypeDef,
@@ -46,7 +46,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAttacksPaginator(Boto3Paginator):
+class ListAttacksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Paginator.ListAttacks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators/#listattackspaginator)
@@ -56,9 +56,9 @@ class ListAttacksPaginator(Boto3Paginator):
         self,
         *,
         ResourceArns: Sequence[str] = ...,
-        StartTime: "TimeRangeTypeDef" = ...,
-        EndTime: "TimeRangeTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        StartTime: TimeRangeTypeDef = ...,
+        EndTime: TimeRangeTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAttacksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
@@ -66,14 +66,17 @@ class ListAttacksPaginator(Boto3Paginator):
         """
 
 
-class ListProtectionsPaginator(Boto3Paginator):
+class ListProtectionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Paginator.ListProtections)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators/#listprotectionspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self,
+        *,
+        InclusionFilters: InclusionProtectionFiltersTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListProtectionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
